env

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package env sources configuration from process environment variables, optionally filtered and trimmed by prefix.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewSource

func NewSource(prefixes ...string) config.Source

NewSource returns a source that loads environment variables. With no prefixes every variable is loaded under its own name; with prefixes, only matching variables are loaded, keyed by the name with the prefix (and one separating underscore) removed.

Types

This section is empty.

Jump to